# remirepo/fedora spec file for cassandra-cpp-driver
#
# Copyright (c) 2015-2020 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#

%global gh_commit   ee2151664314f4efe3d7d00e49677445fe6c8830
%global gh_short    %(c=%{gh_commit}; echo ${c:0:7})
%global gh_owner    datastax
%global gh_project  cpp-driver
%global libname     libcassandra
%global soname      2
#global prever      beta1

Name:          cassandra-cpp-driver
Summary:       DataStax C/C++ Driver for Apache Cassandra
Version:       2.15.3%{?prever:~%{prever}}
Release:       2%{?dist}
License:       ASL 2.0
Group:         System Environment/Libraries

URL:           http://datastax.github.io/cpp-driver/
Source0:       https://github.com/%{gh_owner}/%{gh_project}/archive/%{gh_commit}/%{gh_project}-%{version}%{?prever:-%{prever}}-%{gh_short}.tar.gz

Patch0:        https://patch-diff.githubusercontent.com/raw/datastax/cpp-driver/pull/479.patch

BuildRequires: gcc
BuildRequires: gcc-c++
BuildRequires: cmake >= 2.8.12
BuildRequires: libuv-devel >= 1:1.0
BuildRequires: openssl-devel
BuildRequires: krb5-devel
BuildRequires: zlib-devel


%description
%{summary}.

A modern, feature-rich, and highly tunable C/C++ client library for
Apache Cassandra (1.2+) and DataStax Enterprise (3.1+) using exclusively
Cassandra's native protocol and Cassandra Query Language v3.


%package devel
Summary:    Header files and development libraries for %{name}
Group:      Development/Libraries
Requires:   %{name}%{?_isa} = %{version}-%{release}

%description devel
This package contains the header files and development libraries
for %{name}.


%prep
%setup -q -n %{gh_project}-%{gh_commit}
%patch0 -p1

find examples -name .gitignore -exec rm {} \; -print


%build
%if 0%{?fedora} >= 26 || 0%{?rhel} >= 8
export CXXFLAGS="$RPM_OPT_FLAGS -Wno-implicit-fallthrough"
%endif
%cmake \
  -DCASS_USE_KERBEROS:BOOL=ON \
  -DCASS_USE_OPENSSL:BOOL=ON \
  -DCASS_INSTALL_HEADER_IN_SUBDIR:BOOL=ON \
  -DCASS_INSTALL_HEADER_SUBDIR_NAME:STRING="cassandra" \
  -S .

%if 0%{?cmake_build:1}
%cmake_build
%else
make %{_smp_mflags}
%endif


%install
%if 0%{?cmake_install:1}
%cmake_install
%else
make install  DESTDIR="%{buildroot}"
%endif


%if 0%{?fedora} < 28 && 0%{?rhel} < 8
%post   -p /sbin/ldconfig
%postun -p /sbin/ldconfig
%endif


%files
%{!?_licensedir:%global license %%doc}
%license LICENSE.txt
%{_libdir}/%{libname}.so.%{soname}*


%files devel
%doc *.md
%doc examples
%{_libdir}/%{libname}.so
%{_includedir}/cassandra/
%{_libdir}/pkgconfig/cassandra.pc


%changelog
* Wed Aug 19 2020 Remi Collet <remi@remirepo.net> - 2.15.3-2
- fix cmake usage for F33 build

* Tue Jul 21 2020 Remi Collet <remi@remirepo.net> - 2.15.3-1
- update to 2.15.3
- open https://github.com/datastax/cpp-driver/pull/479
  fix for openssl 1.0.2 on EL-7

* Tue May 12 2020 Remi Collet <remi@remirepo.net> - 2.15.2-1
- update to 2.15.2

* Fri Mar 20 2020 Remi Collet <remi@remirepo.net> - 2.15.1-2
- rebuild 2.15.1 for new tag with our patch merged

* Wed Mar 18 2020 Remi Collet <remi@remirepo.net> - 2.15.1-1
- update to 2.15.1
- drop patch merged upstream
- open https://github.com/datastax/cpp-driver/pull/472
  fix CASS_INSTALL_HEADER_IN_SUBDIR usage

* Wed Jan 15 2020 Remi Collet <remi@remirepo.net> - 2.15.0-1
- update to 2.15.0
- move headers in /usr/include/cassandra
- enable Kerberos support
- fix pkg-config file with patch from
  https://github.com/datastax/cpp-driver/pull/465

* Thu Dec 12 2019 Remi Collet <remi@remirepo.net> - 2.14.1-1
- update to 2.14.1

* Mon Oct 28 2019 Remi Collet <remi@remirepo.net> - 2.14.0-1
- update to 2.14.0
- drop patch merged upstream

* Tue Aug 20 2019 Remi Collet <remi@remirepo.net> - 2.13.0-2
- add upstream patch for GCC 9 from
  https://github.com/datastax/cpp-driver/pull/453

* Thu Jul  4 2019 Remi Collet <remi@remirepo.net> - 2.13.0-1
- update to 2.13.0

* Tue Apr 23 2019 Remi Collet <remi@remirepo.net> - 2.12.0-1
- update to 2.12.0

* Tue Dec 11 2018 Remi Collet <remi@remirepo.net> - 2.11.0-1
- update to 2.11.0
- open https://datastax-oss.atlassian.net/browse/CPP-754
  broken build with GCC 9

* Wed Oct 10 2018 Remi Collet <remi@remirepo.net> - 2.10.0-1
- update to 2.10.0

* Mon Sep 10 2018 Remi Collet <remi@remirepo.net> - 2.10.0~beta1-1
- update to 2.10.0-beta1
- bump dependency on libuv 1.0

* Tue Apr 17 2018 Remi Collet <remi@remirepo.net> - 2.9.0-1
- update to 2.9.0

* Wed Feb 14 2018 Remi Collet <remi@remirepo.net> - 2.8.1-1
- Update to 2.8.1

* Wed Nov 22 2017 Remi Collet <remi@remirepo.net> - 2.8.0-1
- update to 2.8.0

* Wed Sep 20 2017 Remi Collet <remi@remirepo.net> - 2.7.1-1
- update to 2.7.1

* Mon May 22 2017 Remi Collet <remi@remirepo.net> - 2.7.0-1
- update to 2.7.0
- open https://datastax-oss.atlassian.net/browse/CPP-470 - BC break

* Mon Mar 13 2017 Remi Collet <remi@fedoraproject.org> - 2.6.0-2
- add upstream patch for EL-6

* Fri Mar 10 2017 Remi Collet <remi@fedoraproject.org> - 2.6.0-1
- update to 2.6.0
- open https://datastax-oss.atlassian.net/browse/CPP-442
  Broken build on EL-6 64-bit

* Mon Mar  6 2017 Remi Collet <remi@fedoraproject.org> - 2.5.0-2
- use -Wno-implicit-fallthrough, workaround for GCC 7
- open https://datastax-oss.atlassian.net/browse/CPP-438
  Broken build with GCC 7 and OpenSSL 1.1

* Fri Oct 21 2016 Remi Collet <remi@fedoraproject.org> - 2.5.0-1
- update to 2.5.0

* Sat Sep  3 2016 Remi Collet <remi@fedoraproject.org> - 2.4.3-1
- update to 2.4.3

* Wed Jun 29 2016 Remi Collet <remi@fedoraproject.org> - 2.4.2-1
- update to 2.4.2

* Fri Jun 10 2016 Remi Collet <remi@fedoraproject.org> - 2.4.1-1
- update to 2.4.1

* Tue Jun  7 2016 Remi Collet <remi@fedoraproject.org> - 2.4.0-1
- update to 2.4.0

* Fri Feb 12 2016 Remi Collet <remi@fedoraproject.org> - 2.2.2-1
- update to 2.2.2

* Thu Nov 26 2015 Remi Collet <remi@fedoraproject.org> - 2.2.1-1
- update to 2.2.1

* Thu Aug 13 2015 Remi Collet <remi@fedoraproject.org> - 2.1.0-1
- initial package
